.. currentmodule:: ldgm
.. _sec_matlab_api:

==========
MATLAB API
==========

This page provides documentation for the ``ldgm`` MATLAB API to perform efficent matrix algebra with a LDGM precision matrix, as well as code to create an LDGM precision matrix from an LDGM. We recommend starting with with the tutorials, which walk through how to use LDGM precision matrices to efficiently analyze real or simulated GWAS summary statistics. Detailed documentation of the functions in this package are below.


Functions to analyze GWAS summary statistics using LDGM precision matrices
============================================================

.. mat:automodule:: MATLAB
   :members:
   :undoc-members:
   :show-inheritance:

Functions to infer LDGM precision matrices
===================================


.. mat:automodule:: MATLAB.precision
   :members:
   :undoc-members:
   :show-inheritance:


